<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Manage every blog configuration directive'] = 'Gestion des directives de configuration des blogs';
$GLOBALS['__l10n']['Akismet interface for Dotclear'] = 'Interface Akismet pour Dotclear';
$GLOBALS['__l10n']['Generic antispam plugin for Dotclear'] = 'Antispam générique pour Dotclear';
$GLOBALS['__l10n']['Manage post attachments'] = 'Gestion des fichiers attachés';
$GLOBALS['__l10n']['Manage your blogroll'] = 'Gestion de votre liste de liens';
$GLOBALS['__l10n']['Configure your Blowup Theme'] = 'Configurer votre thème Blowup';
$GLOBALS['__l10n']['Legacy modules for dotclear'] = 'Plugin de compatibilité pour Dotclear';
$GLOBALS['__l10n']['Trackback validity check'] = 'Contrôle de validité des rétroliens';
$GLOBALS['__l10n']['Import and Export your blog'] = 'Importez et exportez votre blog';
$GLOBALS['__l10n']['Maintain your installation'] = 'Maintenez votre installation';
$GLOBALS['__l10n']['Serve entries as simple web pages'] = 'Publie des billets comme de simples pages web';
$GLOBALS['__l10n']['Ping services'] = 'Services de signalement';
$GLOBALS['__l10n']['Simple menu for Dotclear'] = 'Menu simple pour Dotclear';
$GLOBALS['__l10n']['Tags for posts'] = 'Mots-clés pour les billets';
$GLOBALS['__l10n']['Theme Editor'] = 'Éditeur de thème';
$GLOBALS['__l10n']['Manage every user preference directive'] = 'Gestion des préférences utilisateur';
$GLOBALS['__l10n']['Widgets for your blog sidebars'] = 'Widgets pour les volets de votre blog';
$GLOBALS['__l10n']['dotclear legacy editor'] = 'éditeur historique de Dotclear';
$GLOBALS['__l10n']['dotclear CKEditor integration'] = 'éditeur CKEditor pour Dotclear';
$GLOBALS['__l10n']['Search engine form'] = 'Formulaire de recherche';
$GLOBALS['__l10n']['List of navigation links'] = 'Liste des liens de navigation';
$GLOBALS['__l10n']['List of selected entries'] = 'Liste des billets sélectionnés';
$GLOBALS['__l10n']['List of available languages'] = 'Liste des langues disponibles';
$GLOBALS['__l10n']['List of categories'] = 'Liste des catégories';
$GLOBALS['__l10n']['Feed subscription links (RSS or Atom)'] = 'Liens de souscription aux flux (RSS ou Atom)';
$GLOBALS['__l10n']['List of last entries from feed (RSS or Atom)'] = 'Liste des derniers billets d\'un flux (RSS or Atom)';
$GLOBALS['__l10n']['Simple text'] = 'Texte simple';
$GLOBALS['__l10n']['List of last entries published'] = 'Liste des derniers billets publiés';
$GLOBALS['__l10n']['List of last comments published'] = 'Liste des derniers commentaires publiés';
$GLOBALS['__l10n']['Tags cloud'] = 'Nuage de mots-clés';
$GLOBALS['__l10n']['List of published pages'] = 'Liste des pages publiées';
$GLOBALS['__l10n']['Blogroll list'] = 'Liste de liens';
$GLOBALS['__l10n']['List of simple menu items'] = 'Liste des éléments de menu simple';
$GLOBALS['__l10n']['Configuration successfully updated'] = 'La configuration a été mise à jour';
$GLOBALS['__l10n']['no'] = 'non';
$GLOBALS['__l10n']['yes'] = 'oui';
$GLOBALS['__l10n']['about:config'] = 'about:config';
$GLOBALS['__l10n']['Settings for %s'] = 'Réglages pour %s';
$GLOBALS['__l10n']['Value'] = 'Valeur';
$GLOBALS['__l10n']['Description'] = 'Description';
$GLOBALS['__l10n']['Goto:'] = 'Aller à : ';
$GLOBALS['__l10n']['Global settings'] = 'Réglages généraux';
$GLOBALS['__l10n']['Akismet spam filter'] = 'Filtre d\'indésirable Akismet';
$GLOBALS['__l10n']['Filtered by %s.'] = 'Filtré par %s.';
$GLOBALS['__l10n']['Filter configuration have been successfully saved.'] = 'La configuration du filtre a été enregistrée.';
$GLOBALS['__l10n']['Akismet API key:'] = 'Clé API Akismet :';
$GLOBALS['__l10n']['API key verified'] = 'Clé API vérifiée';
$GLOBALS['__l10n']['API key not verified'] = 'Clé API non vérifiée';
$GLOBALS['__l10n']['Get your own API key'] = 'Obtenez votre propre clé API';
$GLOBALS['__l10n']['Antispam'] = 'Antispam';
$GLOBALS['__l10n']['All spam comments older than %s day(s) will be automatically deleted.'] = 'Tous les commentaires indésirables âgés d\'au moins %s jour(s) seront supprimés automatiquement.';
$GLOBALS['__l10n']['You can modify this duration in the %s'] = 'Vous pouvez modifier cette durée dans les %s';
$GLOBALS['__l10n']['Delete junk comments older than'] = 'Supprimer les commentaires indésirables âgés de plus de';
$GLOBALS['__l10n']['days'] = 'jours';
$GLOBALS['__l10n']['Set spam filters.'] = 'Régler les filtres de spam.';
$GLOBALS['__l10n']['IP Blacklist / Whitelist Filter'] = 'Filtre de liste noire et blanche d\'IP';
$GLOBALS['__l10n']['Filtered by %1$s with rule %2$s.'] = 'Flitré par %1$s avec la règle %2$s.';
$GLOBALS['__l10n']['IP address has been successfully added.'] = 'L\'adresse IP a été ajoutée.';
$GLOBALS['__l10n']['IP addresses have been successfully removed.'] = 'L\'adresse IP a été retirée.';
$GLOBALS['__l10n']['Blacklist'] = 'Liste noire';
$GLOBALS['__l10n']['Whitelist'] = 'Liste blanche';
$GLOBALS['__l10n']['Add an IP address: '] = 'Ajouter une adresse IP : ';
$GLOBALS['__l10n']['Global IP (used for all blogs)'] = 'IP globale (valable pour tous les blogs)';
$GLOBALS['__l10n']['Add'] = 'Ajouter';
$GLOBALS['__l10n']['No IP address in list.'] = 'Pas d\'adresse IP dans la liste.';
$GLOBALS['__l10n']['IP list'] = 'Liste IP';
$GLOBALS['__l10n']['Local IPs (used only for this blog)'] = 'IP locales (valables seulement pour ce blog)';
$GLOBALS['__l10n']['Global IPs (used for all blogs)'] = 'IP globales (valables pour tous les blogs)';
$GLOBALS['__l10n']['Checks sender IP address against DNSBL servers'] = 'Contrôle l\'adresse IP de l\'émetteur via les serveurs DNSBL';
$GLOBALS['__l10n']['Filtered by %1$s with server %2$s.'] = 'Filtré par %1$s par le serveur %2$s.';
$GLOBALS['__l10n']['The list of DNSBL servers has been succesfully updated.'] = 'La liste des serveurs DNSBL a été mise à jour.';
$GLOBALS['__l10n']['IP Lookup servers'] = 'Serveurs de contrôle d\'IP';
$GLOBALS['__l10n']['Add here a coma separated list of servers.'] = 'Ajouter ici la liste des serveurs séparés par des virgules.';
$GLOBALS['__l10n']['Checks links in comments against surbl.org'] = 'Contrôle les liens des commentaires via surbl.org';
$GLOBALS['__l10n']['Words Blacklist'] = 'Liste de mots interdits';
$GLOBALS['__l10n']['Filtered by %1$s with word %2$s.'] = 'Filtré par %1$s à cause du mot %2$s.';
$GLOBALS['__l10n']['Words have been successfully added.'] = 'Les mots ont été ajoutés.';
$GLOBALS['__l10n']['Word has been successfully added.'] = 'Le mot a été ajouté.';
$GLOBALS['__l10n']['Words have been successfully removed.'] = 'Les mots ont été retirés.';
$GLOBALS['__l10n']['Add a word '] = 'Ajouter un mot ';
$GLOBALS['__l10n']['Global word (used for all blogs)'] = 'Mot global (valable pour tous les blogs)';
$GLOBALS['__l10n']['No word in list.'] = 'Aucun mot dans la liste.';
$GLOBALS['__l10n']['List of bad words'] = 'Liste de mots interdits';
$GLOBALS['__l10n']['Local words (used only for this blog)'] = 'Mots locaux (valables seulement pour ce blog)';
$GLOBALS['__l10n']['Global words (used for all blogs)'] = 'Mots globaux (valables pour tous les blogs)';
$GLOBALS['__l10n']['Delete selected words'] = 'Supprimer les mots sélectionnés';
$GLOBALS['__l10n']['Create default wordlist'] = 'Créer une liste de mots par défaut';
$GLOBALS['__l10n']['This word exists'] = 'Ce mot est déjà présent';
$GLOBALS['__l10n']['No description'] = 'Pas de description';
$GLOBALS['__l10n']['Filtered by %1$s (%2$s)'] = 'Filtré par %1$s (%2$s)';
$GLOBALS['__l10n']['Unknown filter.'] = 'Filtre inconnu.';
$GLOBALS['__l10n']['This comment is a spam:'] = 'Ce commentaire est indésirable :';
$GLOBALS['__l10n']['(including %d spam comment)'] = '(dont %d indésirable)';
$GLOBALS['__l10n']['(including %d spam comments)'] = '(dont %d indésirables)';
$GLOBALS['__l10n']['Spam moderation'] = 'Modération des indésirables';
$GLOBALS['__l10n']['Spam'] = 'Indésirable';
$GLOBALS['__l10n']['Ham'] = 'Désirable';
$GLOBALS['__l10n']['Filter does not exist.'] = 'Ce filtre n\'existe pas.';
$GLOBALS['__l10n']['Filter has no user interface.'] = 'Ce filtre n\'a pas de réglages.';
$GLOBALS['__l10n']['Filters configuration has been successfully saved.'] = 'La configuration des filtres a été enregistrée.';
$GLOBALS['__l10n']['%s configuration'] = 'Configuration de %s';
$GLOBALS['__l10n']['%s filter configuration'] = 'Configuration du filtre %s';
$GLOBALS['__l10n']['Back to filters list'] = 'Retour à la liste des filtres';
$GLOBALS['__l10n']['Information'] = 'Informations';
$GLOBALS['__l10n']['Junk comments:'] = 'Commentaires indésirables :';
$GLOBALS['__l10n']['Published comments:'] = 'Commentaires publiés :';
$GLOBALS['__l10n']['Available spam filters'] = 'Filtres d\'indésirable disponibles';
$GLOBALS['__l10n']['Order'] = 'Ordre';
$GLOBALS['__l10n']['Active'] = 'Actif';
$GLOBALS['__l10n']['Auto Del.'] = 'Auto suppr.';
$GLOBALS['__l10n']['Filter name'] = 'Nom du filtre';
$GLOBALS['__l10n']['Filter configuration'] = 'Configuration du filtre';
$GLOBALS['__l10n']['position'] = 'position';
$GLOBALS['__l10n']['Syndication'] = 'Syndication';
$GLOBALS['__l10n']['Junk comments RSS feed'] = 'Fil RSS des commentaires indésirables';
$GLOBALS['__l10n']['Published comments RSS feed'] = 'Fil RSS des commentaires publiés';
$GLOBALS['__l10n']['Attachments'] = 'Annexes';
$GLOBALS['__l10n']['Attachments (%d)'] = 'Annexes (%d)';
$GLOBALS['__l10n']['remove'] = 'supprimer';
$GLOBALS['__l10n']['No attachment.'] = 'Pas de fichier attaché.';
$GLOBALS['__l10n']['Add files to this entry'] = 'Ajouter des fichiers à la page';
$GLOBALS['__l10n']['Blogroll'] = 'Liste des liens';
$GLOBALS['__l10n']['manage blogroll'] = 'Gestion de la liste des liens';
$GLOBALS['__l10n']['Links'] = 'Liens';
$GLOBALS['__l10n']['Title (optional)'] = 'Titre (optionnel)';
$GLOBALS['__l10n']['All categories'] = 'Toutes les catégories';
$GLOBALS['__l10n']['Display on:'] = 'Afficher :';
$GLOBALS['__l10n']['All pages'] = 'Sur toutes les pages';
$GLOBALS['__l10n']['Home page only'] = 'En page d\'accueil seulement';
$GLOBALS['__l10n']['Except on home page'] = 'Sauf en page d\'accueil';
$GLOBALS['__l10n']['Content only'] = 'Contenu seul (sans boîte englobante)';
$GLOBALS['__l10n']['CSS class:'] = 'Classe CSS supplémentaire pour la boîte englobante :';
$GLOBALS['__l10n']['Offline'] = 'Hors ligne';
$GLOBALS['__l10n']['You must provide a link title'] = 'Vous devez fournir un titre de lien';
$GLOBALS['__l10n']['You must provide a link URL'] = 'Vous devez fournir une URL de lien';
$GLOBALS['__l10n']['You need to provide a XBEL or OPML file.'] = 'Vous devez fournir un fichier XBEL ou OPML.';
$GLOBALS['__l10n']['File is not in XML format.'] = 'Ce fichier n\'est pas au format XML.';
$GLOBALS['__l10n']['No such link or title'] = 'Pas de lien ou de titre';
$GLOBALS['__l10n']['Link has been successfully updated'] = 'Le lien a été mis à jour.';
$GLOBALS['__l10n']['Category has been successfully updated'] = 'La catégorie a été mise à jour.';
$GLOBALS['__l10n']['Return to blogroll'] = 'Retourner à la liste des liens';
$GLOBALS['__l10n']['Edit category'] = 'Modifier la catégorie';
$GLOBALS['__l10n']['Edit link'] = 'Modifier le lien';
$GLOBALS['__l10n']['XFN information'] = 'Informations XFN';
$GLOBALS['__l10n']['_xfn_Me'] = '_xfn_Me';
$GLOBALS['__l10n']['_xfn_Another link for myself'] = '_xfn_Another link for myself';
$GLOBALS['__l10n']['_xfn_Friendship'] = '_xfn_Friendship';
$GLOBALS['__l10n']['_xfn_Contact'] = '_xfn_Contact';
$GLOBALS['__l10n']['_xfn_Acquaintance'] = '_xfn_Acquaintance';
$GLOBALS['__l10n']['_xfn_Friend'] = '_xfn_Friend';
$GLOBALS['__l10n']['_xfn_Physical'] = '_xfn_Physical';
$GLOBALS['__l10n']['_xfn_Met'] = '_xfn_Met';
$GLOBALS['__l10n']['_xfn_Professional'] = '_xfn_Professional';
$GLOBALS['__l10n']['_xfn_Co-worker'] = '_xfn_Co-worker';
$GLOBALS['__l10n']['_xfn_Colleague'] = '_xfn_Colleague';
$GLOBALS['__l10n']['_xfn_Geographical'] = '_xfn_Geographical';
$GLOBALS['__l10n']['_xfn_Co-resident'] = '_xfn_Co-resident';
$GLOBALS['__l10n']['_xfn_Neighbor'] = '_xfn_Neighbor';
$GLOBALS['__l10n']['_xfn_Family'] = '_xfn_Family';
$GLOBALS['__l10n']['_xfn_Child'] = '_xfn_Child';
$GLOBALS['__l10n']['_xfn_Parent'] = '_xfn_Parent';
$GLOBALS['__l10n']['_xfn_Sibling'] = '_xfn_Sibling';
$GLOBALS['__l10n']['_xfn_Spouse'] = '_xfn_Spouse';
$GLOBALS['__l10n']['_xfn_Kin'] = '_xfn_Kin';
$GLOBALS['__l10n']['_xfn_Romantic'] = '_xfn_Romantic';
$GLOBALS['__l10n']['_xfn_Muse'] = '_xfn_Muse';
$GLOBALS['__l10n']['_xfn_Crush'] = '_xfn_Crush';
$GLOBALS['__l10n']['_xfn_Date'] = '_xfn_Date';
$GLOBALS['__l10n']['_xfn_Sweetheart'] = '_xfn_Sweetheart';
$GLOBALS['__l10n']['Nothing to import'] = 'Rien à importer';
$GLOBALS['__l10n']['links have been successfully imported.'] = 'Les liens ont été importés.';
$GLOBALS['__l10n']['Import operation cancelled.'] = 'L\'importation a été annulée.';
$GLOBALS['__l10n']['Link has been successfully created.'] = 'Le lien a été créé.';
$GLOBALS['__l10n']['category has been successfully created.'] = 'La catégorie a été créée.';
$GLOBALS['__l10n']['Items have been successfully removed.'] = 'Les éléments ont été retirés.';
$GLOBALS['__l10n']['Items order has been successfully updated'] = 'L\'ordre des éléments a été mis à jour.';
$GLOBALS['__l10n']['URL'] = 'URL';
$GLOBALS['__l10n']['Lang'] = 'Langue';
$GLOBALS['__l10n']['select this link'] = 'sélectionner ce lien';
$GLOBALS['__l10n']['Delete selected links'] = 'Supprimer les liens sélectionnés';
$GLOBALS['__l10n']['Are you sure you want to delete selected links?'] = 'Êtes-vous sûr de vouloir supprimer ces liens ?';
$GLOBALS['__l10n']['The link list is empty.'] = 'La liste des liens est vide.';
$GLOBALS['__l10n']['Add a new link'] = 'Ajouter un nouveau lien';
$GLOBALS['__l10n']['Add a category'] = 'Ajouter une catégorie';
$GLOBALS['__l10n']['Import links'] = 'Importer des liens';
$GLOBALS['__l10n']['OPML or XBEL File:'] = 'Fichier OPML ou XBEL :';
$GLOBALS['__l10n']['Import'] = 'Importer';
$GLOBALS['__l10n']['Light linear gradient'] = 'Dégradé linéaire clair';
$GLOBALS['__l10n']['Medium linear gradient'] = 'Dégragé linéaire moyen';
$GLOBALS['__l10n']['Dark linear gradient'] = 'Dégradé linéaire foncé';
$GLOBALS['__l10n']['Solid color'] = 'Couleur pleine';
$GLOBALS['__l10n']['Custom...'] = 'Personnalisé…';
$GLOBALS['__l10n']['Theme configuration has been successfully updated.'] = 'La configuration du thème a été enregistrée.';
$GLOBALS['__l10n']['Blowup configuration'] = 'Configuration de Blowup';
$GLOBALS['__l10n']['Predefined styles'] = 'Styles prédéfinis';
$GLOBALS['__l10n']['Apply code'] = 'Appliquer le code';
$GLOBALS['__l10n']['Choose a predefined style'] = 'Sélectionnez un style prédéfini';
$GLOBALS['__l10n']['Back to Blog appearance'] = 'Retour à l\'apparence du blog';
$GLOBALS['__l10n']['For the following reasons, images cannot be created. You won\'t be able to change some background properties.'] = 'Pour les raisons suivantes, les images n\'ont pu être créées. Vous ne pourrez pas changer certaines propriétés de fond.';
$GLOBALS['__l10n']['Customization'] = 'Personnalisation';
$GLOBALS['__l10n']['General'] = 'Général';
$GLOBALS['__l10n']['Background color:'] = 'Couleur de fond :';
$GLOBALS['__l10n']['Background color fill:'] = 'Remplissage de la couleur du fond :';
$GLOBALS['__l10n']['Main text font:'] = 'Police du texte principal :';
$GLOBALS['__l10n']['Main text font size:'] = 'Taille de police du texte principal :';
$GLOBALS['__l10n']['Main text color:'] = 'Couleur du texte principal :';
$GLOBALS['__l10n']['Text line height:'] = 'Hauteur des lignes de texte :';
$GLOBALS['__l10n']['Links color:'] = 'Couleur des liens :';
$GLOBALS['__l10n']['Visited links color:'] = 'Couleur des liens visités :';
$GLOBALS['__l10n']['Focus links color:'] = 'Couleur des liens ayant le focus :';
$GLOBALS['__l10n']['Page top'] = 'Haut de page';
$GLOBALS['__l10n']['Prelude color:'] = 'Couleur du prélude :';
$GLOBALS['__l10n']['Hide main title'] = 'Cacher le titre principal';
$GLOBALS['__l10n']['Main title font:'] = 'Police du titre principal :';
$GLOBALS['__l10n']['Main title font size:'] = 'Taille de police du titre principal :';
$GLOBALS['__l10n']['Main title color:'] = 'Couleur du titre principal :';
$GLOBALS['__l10n']['Main title alignment:'] = 'Alignement du titre principal :';
$GLOBALS['__l10n']['center'] = 'centré';
$GLOBALS['__l10n']['left'] = 'à gauche';
$GLOBALS['__l10n']['right'] = 'à droite';
$GLOBALS['__l10n']['Main title position (x:y)'] = 'Position du titre principal (x:y)';
$GLOBALS['__l10n']['Top image'] = 'Image de haut de page';
$GLOBALS['__l10n']['Choose "Custom..." to upload your own image.'] = 'Choisissez « Personnalisé… » pour téléverser votre propre image.';
$GLOBALS['__l10n']['Add your image:'] = 'Ajouter votre image :';
$GLOBALS['__l10n']['JPEG or PNG file, 800 pixels wide, maximum size %s'] = 'Fichier JPEG ou PNG, 800 pixels de large maximum, taille maximum de %s';
$GLOBALS['__l10n']['Sidebar'] = 'Volet';
$GLOBALS['__l10n']['Sidebar position:'] = 'Position du volet :';
$GLOBALS['__l10n']['Sidebar text font:'] = 'Police du texte du volet :';
$GLOBALS['__l10n']['Sidebar text font size:'] = 'Taille de police du texte du volet :';
$GLOBALS['__l10n']['Sidebar text color:'] = 'Couleur du texte du volet :';
$GLOBALS['__l10n']['Sidebar titles font:'] = 'Police des titres du volet :';
$GLOBALS['__l10n']['Sidebar titles font size:'] = 'Taille de police des titres du volet :';
$GLOBALS['__l10n']['Sidebar titles color:'] = 'Couleur des titres du volet :';
$GLOBALS['__l10n']['Sidebar 2nd level titles font:'] = 'Police des titres secondaires du volet :';
$GLOBALS['__l10n']['Sidebar 2nd level titles font size:'] = 'Taille de police des titres secondaires du volet :';
$GLOBALS['__l10n']['Sidebar 2nd level titles color:'] = 'Couleur des titres secondaires du volet :';
$GLOBALS['__l10n']['Sidebar lines color:'] = 'Couleur des lignes du volet :';
$GLOBALS['__l10n']['Sidebar links color:'] = 'Couleur des liens du volet :';
$GLOBALS['__l10n']['Sidebar visited links color:'] = 'Couleur des liens visités du volet :';
$GLOBALS['__l10n']['Sidebar focus links color:'] = 'Couleur des liens du volet ayant le focus :';
$GLOBALS['__l10n']['Date title font:'] = 'Police du titre des dates :';
$GLOBALS['__l10n']['Date title font size:'] = 'Taille de police du titre des dates :';
$GLOBALS['__l10n']['Date title color:'] = 'Couleur du titre des dates :';
$GLOBALS['__l10n']['Entry title font:'] = 'Police du titre des billets :';
$GLOBALS['__l10n']['Entry title font size:'] = 'Taille de police du titre des billets :';
$GLOBALS['__l10n']['Entry title color:'] = 'Couleur du titre des billets :';
$GLOBALS['__l10n']['Comment background color:'] = 'Couleur de fond des commentaires :';
$GLOBALS['__l10n']['Comment text color:'] = 'Couleur du texte des commentaires :';
$GLOBALS['__l10n']['My comment background color:'] = 'Couleur de fond de mes commentaires :';
$GLOBALS['__l10n']['My comment text color:'] = 'Couleur du texte de mes commentaires :';
$GLOBALS['__l10n']['Footer'] = 'Pied de page';
$GLOBALS['__l10n']['Footer font:'] = 'Police du pied de page :';
$GLOBALS['__l10n']['Footer font size:'] = 'Taille de police du pied de page :';
$GLOBALS['__l10n']['Footer color:'] = 'Couleur du pied de page :';
$GLOBALS['__l10n']['Footer links color:'] = 'Couleur des liens du pied de page :';
$GLOBALS['__l10n']['Footer background color:'] = 'Couleur de fond du pied de page :';
$GLOBALS['__l10n']['Additional CSS'] = 'Style additionnel';
$GLOBALS['__l10n']['Any additional CSS styles (must be written using the CSS syntax):'] = 'Styles CSS additionnels (doivent être écrits selon la syntaxe CSS) :';
$GLOBALS['__l10n']['Configuration import / export'] = 'Configuration de l\'import/export';
$GLOBALS['__l10n']['You can share your configuration using the following code. To apply a configuration, paste the code, click on "Apply code" and save.'] = 'Vous pouvez partager votre configuration en utilisant le code suivant. Pour appliquer une configuration, copiez le code, cliquez sur « Appliquer le code », puis sauvegardez.';
$GLOBALS['__l10n']['Copy this code:'] = 'Copier ce code :';
$GLOBALS['__l10n']['default'] = 'défaut';
$GLOBALS['__l10n']['Unable to create css file.'] = 'Impossible de créer le fichier css.';
$GLOBALS['__l10n']['Unable to open image.'] = 'Impossible d\'ouvrir l\'image.';
$GLOBALS['__l10n']['The configuration has been updated.'] = 'La configuration a été enregistrée.';
$GLOBALS['__l10n']['Media chooser'] = 'Sélecteur de média';
$GLOBALS['__l10n']['Link to an entry'] = 'Lien vers une entrée';
$GLOBALS['__l10n']['Link'] = 'Lien';
$GLOBALS['__l10n']['visual'] = 'visuel';
$GLOBALS['__l10n']['source'] = 'source';
$GLOBALS['__l10n']['You can use the following shortcuts to format your text.'] = 'Vous pouvez utiliser les raccourcis suivants pour formater votre texte.';
$GLOBALS['__l10n']['-- none --'] = '-- aucun --';
$GLOBALS['__l10n']['-- block format --'] = '-- format de bloc --';
$GLOBALS['__l10n']['Paragraph'] = 'Paragraphe';
$GLOBALS['__l10n']['Level 1 header'] = 'Entête de niveau 1';
$GLOBALS['__l10n']['Level 2 header'] = 'Entête de niveau 2';
$GLOBALS['__l10n']['Level 3 header'] = 'Entête de niveau 3';
$GLOBALS['__l10n']['Level 4 header'] = 'Entête de niveau 4';
$GLOBALS['__l10n']['Level 5 header'] = 'Entête de niveau 5';
$GLOBALS['__l10n']['Level 6 header'] = 'Entête de niveau 6';
$GLOBALS['__l10n']['Strong emphasis'] = 'Emphase forte';
$GLOBALS['__l10n']['Emphasis'] = 'Emphase';
$GLOBALS['__l10n']['Inserted'] = 'Inséré';
$GLOBALS['__l10n']['Deleted'] = 'Supprimé';
$GLOBALS['__l10n']['Inline quote'] = 'Citation en ligne';
$GLOBALS['__l10n']['Code'] = 'Code';
$GLOBALS['__l10n']['Line break'] = 'Retour à la ligne';
$GLOBALS['__l10n']['Blockquote'] = 'Bloc de citation';
$GLOBALS['__l10n']['Preformated text'] = 'Texte préformaté';
$GLOBALS['__l10n']['Unordered list'] = 'Liste non ordonnée';
$GLOBALS['__l10n']['Ordered list'] = 'Liste ordonnée';
$GLOBALS['__l10n']['URL?'] = 'URL ?';
$GLOBALS['__l10n']['Language?'] = 'Langue ?';
$GLOBALS['__l10n']['External image'] = 'Image externe';
$GLOBALS['__l10n']['Remove text formating'] = 'Retirer le formatage du texte';
$GLOBALS['__l10n']['Checks trackback source for a link to the post'] = 'Contrôle si la source du rétrolien comporte un lien vers le billet';
$GLOBALS['__l10n']['Import/Export'] = 'Import/Export';
$GLOBALS['__l10n']['Flat file export'] = 'Fichier d\'exportation « à plat »';
$GLOBALS['__l10n']['Exports a blog or a full Dotclear installation to flat file.'] = 'Exporte un blog ou une installation Dotclear complète vers un fichier « à plat ».';
$GLOBALS['__l10n']['Export file not found.'] = 'Le fichier d\'export n\'a pas été trouvé.';
$GLOBALS['__l10n']['Failed to compress export file.'] = 'Impossible de compresser le fichier d\'export.';
$GLOBALS['__l10n']['Single blog'] = 'Blog simple';
$GLOBALS['__l10n']['This will create an export of your current blog: %s'] = 'Cela créera un export du blog courant : %s';
$GLOBALS['__l10n']['Compress file'] = 'Compresser le fichier';
$GLOBALS['__l10n']['You may also want to download your media directory as a zip file'] = 'Vous pouvez également télécharger votre répertoire de média sous forme de fichier archive zip';
$GLOBALS['__l10n']['Export'] = 'Export';
$GLOBALS['__l10n']['Multiple blogs'] = 'Tous les blogs';
$GLOBALS['__l10n']['This will create an export of all the content of your database.'] = 'Cela créera un export avec tout le contenu de votre base de données.';
$GLOBALS['__l10n']['Congratulation!'] = 'Bravo !';
$GLOBALS['__l10n']['Your blog has been successfully imported. Welcome on Dotclear 2!'] = 'Votre blog a été importé. Bienvenue sur Dotclear 2 !';
$GLOBALS['__l10n']['Why don\'t you blog this now?'] = 'Pourquoi ne bloguez-vous pas cela maintenant ?';
$GLOBALS['__l10n']['or'] = 'ou';
$GLOBALS['__l10n']['visit your dashboard'] = 'voir votre tableau de bord';
$GLOBALS['__l10n']['Dotclear 1.2 import'] = 'Importation depuis Dotclear 1.2';
$GLOBALS['__l10n']['Import a Dotclear 1.2 installation into your current blog.'] = 'Importer une installation Dotclear 1.2 dans votre blog courant.';
$GLOBALS['__l10n']['Import the content of a Dotclear 1.2\'s blog in the current blog: %s.'] = 'Importer le contenu d\'un blog Dotclear 1.2 comme nouveau contenu dans le blog courant : %s.';
$GLOBALS['__l10n']['Please note that this process will empty your categories, blogroll, entries and comments on the current blog.'] = 'Notez que cela supprimera les catégories, liste de liens, billets et commentaires actuels du blog courant. ';
$GLOBALS['__l10n']['General information'] = 'Informations générales';
$GLOBALS['__l10n']['Import my blog now'] = 'Importer mon blog maintenant';
$GLOBALS['__l10n']['We first need some information about your old Dotclear 1.2 installation.'] = 'Nous avons besoin au préalable de quelques informations à propos de votre installation Dotclear 1.2.';
$GLOBALS['__l10n']['Entries import options'] = 'Options d\'importation des billets';
$GLOBALS['__l10n']['Number of entries to import at once:'] = 'Nombre d\'éléments à importer à chaque passe :';
$GLOBALS['__l10n']['Importing users'] = 'Importation des utilisateurs';
$GLOBALS['__l10n']['Importing categories'] = 'Importation des catégories';
$GLOBALS['__l10n']['Importing blogroll'] = 'Importation de la liste des liens';
$GLOBALS['__l10n']['Importing entries from %d to %d / %d'] = 'Importation des éléments %d à %d / %d';
$GLOBALS['__l10n']['Please read carefully'] = 'Lisez soigneusement';
$GLOBALS['__l10n']['Every newly imported user has received a random password and will need to ask for a new one by following the "I forgot my password" link on the login page (Their registered email address has to be valid.)'] = 'Chaque utilisateur nouvellement importé a reçu un mot de passe aléatoire et devra en demander un nouveau en cliquant sur le lien « J\'ai oublié mon mot de passe » sur la page d\'authentification (son adresse email doit être valide).';
$GLOBALS['__l10n']['Please note that Dotclear 2 has a new URL layout. You can avoid broken links by installing <a href="%s">DC1 redirect</a> plugin and activate it in your blog configuration.'] = 'Notez que Dotclear a un nouveau schéma d\'URL. Vous pouvez éviter les liens brisés en installant le plugin <a href="%s">DC1 redirect</a> et en l\'activant dans la configuration de votre blog.';
$GLOBALS['__l10n']['next step'] = 'Étape suivante';
$GLOBALS['__l10n']['Depending on the size of your blog, it could take a few minutes.'] = 'Cela peut prendre plusieurs minutes en fonction de la taille de votre blog.';
$GLOBALS['__l10n']['Dotclear tables not found'] = 'Les tables Dotclear n\'ont pas été trouvées';
$GLOBALS['__l10n']['RSS or Atom feed import'] = 'Importation d\'un flux RSS ou Atom';
$GLOBALS['__l10n']['Add a feed content to the blog.'] = 'Ajouter les contenus d\'un flux au blog.';
$GLOBALS['__l10n']['Cannot retrieve feed URL.'] = 'Impossible de trouver l\'URL du flux.';
$GLOBALS['__l10n']['No items in feed.'] = 'Aucun élément dans le flux';
$GLOBALS['__l10n']['Content successfully imported.'] = 'Le contenu a été importé.';
$GLOBALS['__l10n']['Add a feed content to the current blog: <strong>%s</strong>.'] = 'Ajouter les contenus d\'un flux au blog courant : <strong>%s</strong>.';
$GLOBALS['__l10n']['Feed URL:'] = 'URL du flux :';
$GLOBALS['__l10n']['Flat file import'] = 'Importation d\'un fichier « à plat »';
$GLOBALS['__l10n']['Imports a blog or a full Dotclear installation from flat file.'] = 'Importe un blog ou une installation Dotclear complète depuis un fichier « à plat ».';
$GLOBALS['__l10n']['Single blog successfully imported.'] = 'Le blog a été importé.';
$GLOBALS['__l10n']['Are you sure you want to import a full backup file?'] = 'Êtes-vous sûr de vouloir importer un fichier de sauvegarde complet ?';
$GLOBALS['__l10n']['This will import a single blog backup as new content in the current blog: <strong>%s</strong>.'] = 'Cela importera une sauvegarde d\'un blog comme nouveau contenu du blog courant : <strong>%s</strong>.';
$GLOBALS['__l10n']['Upload a backup file'] = 'Téléversez un fichier de sauvegarde';
$GLOBALS['__l10n']['maximum size %s'] = 'taille maximum de %s';
$GLOBALS['__l10n']['or pick up a local file in your public directory'] = 'ou sélectionnez un fichier local présent dans votre répertoire de médias';
$GLOBALS['__l10n']['This will reset all the content of your database, except users.'] = 'Attention : Cela supprimera au préalable tout le contenu de votre base de données à l\'exception des utilisateurs.';
$GLOBALS['__l10n']['Another file with same name exists.'] = 'Un autre fichier portant ce nom existe déjà.';
$GLOBALS['__l10n']['Failed to extract backup file.'] = 'Impossible d\'extraire le fichier de sauvegarde.';
$GLOBALS['__l10n']['No backup in compressed file.'] = 'Aucune sauvegarde dans le fichier compressé.';
$GLOBALS['__l10n']['WordPress import'] = 'Importation WordPress';
$GLOBALS['__l10n']['Import a WordPress installation into your current blog.'] = 'Importe une installation WordPress dans le blog courant.';
$GLOBALS['__l10n']['This will import your WordPress content as new content in the current blog: %s.'] = 'Cela importera le contenu WordPress comme un nouveau contenu dans le blog courant : %s.';
$GLOBALS['__l10n']['We first need some information about your old WordPress installation.'] = 'Nous avons besoin au préalable de quelques informations au sujet de votre ancienne installation WordPress.';
$GLOBALS['__l10n']['WordPress and Dotclear\'s handling of categories are quite different. You can assign several categories to a single post in WordPress. In the Dotclear world, we see it more like "One category, several tags." Therefore Dotclear can only import one category per post and will chose the lowest numbered one. If you want to keep a trace of every category, you can import them as tags, with an optional prefix.'] = 'La gestion des catégories chez WordPress et Dotclear est tout à fait différente. Vous pouvez assigner plusieurs catégories à un seul billet dans WordPress. Dans le monde Dotclear, nous le voyons davantage comme « une catégorie, plusieurs mots-clés ». Par conséquent Dotclear peut seulement importer une catégorie par billet et il choisira celui de plus petit numéro. Si vous voulez conserver une trace de chaque catégorie, vous pouvez les importer sous forme de mots-clés, avec un préfixe optionnel.';
$GLOBALS['__l10n']['On the other hand, in WordPress, a post can not be uncategorized, and a default installation has a first category labelised <i>"Uncategorized"</i>.If you did not change that category, you can just ignore it while importing your blog, as Dotclear allows you to actually keep your posts uncategorized.'] = 'D\'autre part, dans WordPress, un billet ne peut pas être sans catégorie, et une installation par défaut possède systématiquement une première catégorie nommée <i>« sans catégorie »</i>. Si vous n\'avez pas changé cette catégorie, vous pouvez simplement l\'ignorer lors de l\'importation sur votre blog, puisque Dotclear vous permet réellement de conserver votre message sans catégorie.';
$GLOBALS['__l10n']['Ignore the first category:'] = 'Ignorer la première catégorie :';
$GLOBALS['__l10n']['Import lowest numbered category on posts:'] = 'Importer la catégorie ayant le plus faible numéro dans les billets :';
$GLOBALS['__l10n']['Import all categories as tags:'] = 'Importer toutes les catégories comme des mots-clés :';
$GLOBALS['__l10n']['Prefix such tags with:'] = 'Préfixer les mots-clés avec :';
$GLOBALS['__l10n']['Content filters'] = 'Filtres de contenu';
$GLOBALS['__l10n']['You may want to process your post and/or comment content with the following filters.'] = 'Vous pouvez formater le contenu de vos billets et commentaires avec les filtres suivants.';
$GLOBALS['__l10n']['Post content formatter:'] = 'Formatage du contenu des billets :';
$GLOBALS['__l10n']['Comment content formatter:'] = 'Formatage du contenu des commentaires :';
$GLOBALS['__l10n']['WordPress tables not found'] = 'Les tables WordPress n\'ont pu être trouvées.';
$GLOBALS['__l10n']['No file to read.'] = 'Aucun fichier à lire.';
$GLOBALS['__l10n']['File is not a DotClear backup.'] = 'Ce fichier n\'est pas un fichier de sauvegarde Dotclear.';
$GLOBALS['__l10n']['File is not a single blog export.'] = 'Ce fichier n\'est pas une exportation d\'un blog.';
$GLOBALS['__l10n']['Error raised at line %s'] = 'Erreur détectée ligne %s';
$GLOBALS['__l10n']['File is not a full export.'] = 'Ce fichier n\'est pas un fichier de sauvegarde complet.';
$GLOBALS['__l10n']['ID of "%3$s" does not match on record "%1$s" at line %2$s of backup file.'] = 'L\'ID de "%3$s" ne correspond pas dans l\'enregistrement "%1$s" à la ligne %2$s du fichier de sauvegarde.';
$GLOBALS['__l10n']['Database export'] = 'Exporter la base de données';
$GLOBALS['__l10n']['Download database of current blog'] = 'Télécharger la base de données du blog courant';
$GLOBALS['__l10n']['Download database of all blogs'] = 'Télécharger la base de données de tous les blogs';
$GLOBALS['__l10n']['Please wait...'] = 'Veuillez patientez…';
$GLOBALS['__l10n']['Export functions are in the page %s.'] = 'Les fonctions d\'export sont dans la page de %s.';
$GLOBALS['__l10n']['Maintenance'] = 'Maintenance';
$GLOBALS['__l10n']['Servicing'] = 'Entretien';
$GLOBALS['__l10n']['Tools to maintain the performance of your blogs.'] = 'Outils pour maintenir les performances de vos blogs.';
$GLOBALS['__l10n']['Backup'] = 'Sauvegarde';
$GLOBALS['__l10n']['Tools to back up your content.'] = 'Outils de sauvegarde du contenu';
$GLOBALS['__l10n']['Development'] = 'Développement';
$GLOBALS['__l10n']['Tools to assist in development of plugins, themes and core.'] = 'Outils pour aider au developpement de plugins, thèmes et au core.';
$GLOBALS['__l10n']['Optimize'] = 'Optimiser';
$GLOBALS['__l10n']['Count and index'] = 'Compter et indexer';
$GLOBALS['__l10n']['Purge'] = 'Purger';
$GLOBALS['__l10n']['Other'] = 'Autre';
$GLOBALS['__l10n']['Current blog'] = 'Blog courant';
$GLOBALS['__l10n']['All blogs'] = 'Tous les blogs';
$GLOBALS['__l10n']['Maintain translations'] = 'Maintenir les traductions';
$GLOBALS['__l10n']['Translations'] = 'Traductions';
$GLOBALS['__l10n']['One task to execute'][0] = 'Une tâche à exécuter';
$GLOBALS['__l10n']['One task to execute'][1] = '%s tâches à exécuter';
$GLOBALS['__l10n']['This task has never been executed.'] = 'Cette tâche n\'a jamais été exécutée.';
$GLOBALS['__l10n']['Last execution of this task was on %s.'] = 'La dernière exécution de cette tâches était le %s.';
$GLOBALS['__l10n']['There is a task to execute.'][0] = 'Il y a une tâche à exécuter.';
$GLOBALS['__l10n']['There is a task to execute.'][1] = 'Il y a %s tâches à exécuter.';
$GLOBALS['__l10n']['Manage tasks'] = 'Gérer les tâches';
$GLOBALS['__l10n']['Display overdue tasks counter on maintenance dashboard icon'] = 'Afficher le nombre de tâches en retard sur l\'icône Maintenance du tableau de bord';
$GLOBALS['__l10n']['Display overdue tasks list on dashboard items'] = 'Afficher la liste des tâches en retard dans un module du tableau de bord';
$GLOBALS['__l10n']['Failed to execute task.'] = 'Impossible d\'exécuter la tâche.';
$GLOBALS['__l10n']['Task successfully executed.'] = 'La tâche a été exécutée.';
$GLOBALS['__l10n']['Empty templates cache directory'] = 'Vider le répertoire de cache des « templates »';
$GLOBALS['__l10n']['Templates cache directory emptied.'] = 'Le répertoire de cache des « templates » a été vidé.';
$GLOBALS['__l10n']['Failed to empty templates cache directory.'] = 'Impossible de vider le répertoire de cache des « templates ».';
$GLOBALS['__l10n']['It may be useful to empty this cache when modifying a theme\'s .html or .css files (or when updating a theme or plugin). Notice : with some hosters, the templates cache cannot be emptied with this plugin. You may then have to delete the directory <strong>/cbtpl/</strong> directly on the server with your FTP software.'] = 'La suppression du répertoire du cache des templates peut se révéler nécessaire lors de modifications dans les fichiers .html ou .css d\'un thème (voire lors d\'un changement de thème ou de mise à jour de plugin). Attention : chez certains hébergeurs (Free par exemple), le cache du répertoire des templates ne peut pas être vidé grâce à l\'extension Maintenance, il faut supprimer le répertoire <strong>cbtpl</strong> situé dans le répertoire cache (dotclear/cache par défaut) avec un logiciel FTP.';
$GLOBALS['__l10n']['Count again comments and trackbacks'] = 'Recompter les commentaires et rétroliens';
$GLOBALS['__l10n']['Comments and trackback counted.'] = 'Les commentaires et rétroliens ont été recomptés.';
$GLOBALS['__l10n']['Failed to count comments and trackbacks.'] = 'Impossible de recompter les commentaires et rétroliens.';
$GLOBALS['__l10n']['Count again comments and trackbacks allows to check their exact numbers. This operation can be useful when importing from another blog platform (or when migrating from dotclear 1 to dotclear 2).'] = 'Recompter commentaires et des rétroliens a pour effet de donner le nombre exact de ceux-ci pour chaque billet. Cette opération peut se révéler utile lors de l\'import d\'un blog d\'une autre plateforme (ou d\'une migration de Dotclear 1 vers Dotclear 2).';
$GLOBALS['__l10n']['Search engine index'] = 'Index du moteur de recherche';
$GLOBALS['__l10n']['Index all comments for search engine'] = 'Indexer tous les commentaires pour le moteur de recherche';
$GLOBALS['__l10n']['Next'] = 'Suivant';
$GLOBALS['__l10n']['Indexing comment %d to %d.'] = 'Indexation des commentaires %d à %d.';
$GLOBALS['__l10n']['Comments index done.'] = 'L\'indexation des commentaires a été effectuée.';
$GLOBALS['__l10n']['Failed to index comments.'] = 'Impossible d\'indexer les commentaires.';
$GLOBALS['__l10n']['Index all comments and trackbacks in search engine index. This operation is necessary, after importing content in your blog, to use internal search engine, on public and private pages.'] = 'Indexer tous les commentaires et rétroliens dans le moteur de recherche. Cette opération s\'effectue généralement suite à un import afin d\'obtenir des résultats lors des recherches, aussi bien depuis l\'administration du blog qu\'en partie publique.';
$GLOBALS['__l10n']['Index all entries for search engine'] = 'Indexer tous les billets pour le moteur de recherche';
$GLOBALS['__l10n']['Indexing entry %d to %d.'] = 'Indexation des billets %d à %d.';
$GLOBALS['__l10n']['Entries index done.'] = 'L\'indexation des billets a été effectuée.';
$GLOBALS['__l10n']['Failed to index entries.'] = 'Impossible d\'indexer les billets.';
$GLOBALS['__l10n']['Index all entries in search engine index. This operation is necessary, after importing content in your blog, to use internal search engine, on public and private pages.'] = 'Indexer tous les billets dans le moteur de recherche. Cette opération s\'effectue généralement suite à un import afin d\'obtenir des résultats lors des recherches, aussi bien depuis l\'administration du blog qu\'en partie publique.';
$GLOBALS['__l10n']['Delete all logs'] = 'Supprimer tous les journaux (logs)';
$GLOBALS['__l10n']['Logs deleted.'] = 'Les journaux ont été supprimés.';
$GLOBALS['__l10n']['Failed to delete logs.'] = 'Impossible de supprimer les journaux.';
$GLOBALS['__l10n']['Logs record all activity and connection to your blog history. Unless you need to keep this history, consider deleting these logs from time to time.'] = 'Sauf si vous avez un besoin précis de conservation des activités de connexion sur votre blog, pensez à vider régulièrement la table des journaux : elle contient l\'enregistrement de chaque connexion à l\'administration et des opérations qui s\'y sont déroulées.';
$GLOBALS['__l10n']['Entries metadata'] = 'Métadonnées des billets';
$GLOBALS['__l10n']['Synchronize entries metadata'] = 'Synchroniser les métadonnées des billets';
$GLOBALS['__l10n']['Synchronize entry %d to %d.'] = 'Synchronisation des billets %d à %d.';
$GLOBALS['__l10n']['Entries metadata synchronize done.'] = 'La synchronisation des métadonnées des billets a été effectuée.';
$GLOBALS['__l10n']['Failed to synchronize entries metadata.'] = 'Impossible de synchroniser les métadonnées des billets.';
$GLOBALS['__l10n']['Synchronize all entries metadata could be useful after importing content in your blog or do bad operation on database tables.'] = 'La synchronisation des métadonnées des billets peut être utile après l\'import de contenu dans votre blog ou après une mauvaise opération sur la base de données.';
$GLOBALS['__l10n']['Optimise database'] = 'Optimise la base de données';
$GLOBALS['__l10n']['optimize tables'] = 'Optimiser les tables';
$GLOBALS['__l10n']['Optimization successful.'] = 'L\'optimisation a été effectuée.';
$GLOBALS['__l10n']['Failed to optimize tables.'] = 'Impossible d\'optimiser les tables.';
$GLOBALS['__l10n']['After numerous delete or update operations on Dotclear\'s database, it gets fragmented. Optimizing will allow to defragment it. It has no incidence on your data\'s integrity. It is recommended to optimize before any blog export.'] = 'Au fur at à mesure des suppressions ou modifications dans vos billets, les tables de la base de données se fragmentent. L\'opération d\'optimisation permet de compacter celles-ci. Cette opération n\'a aucun impact sur l\'intégrité de vos données. Il est fortement conseillé d\'optimiser la base de données avant tout export de blog.';
$GLOBALS['__l10n']['Download media folder of current blog'] = 'Télécharger la médiathèque du blog courant';
$GLOBALS['__l10n']['It may be useful to backup your media folder. This compress all content of media folder into a single zip file. Notice : with some hosters, the media folder cannot be compressed with this plugin if it is too big.'] = 'Il peut être utile de sauvegarder votre médiathèque. Ceci comprime tout le contenu du répertoire de média dans un seul fichier Zip. Remarque : chez certains hébergeurs, la médiathèque ne peut pas être compressée avec ce plugin si elle est trop grande.';
$GLOBALS['__l10n']['Download active theme of current blog'] = 'Télécharger le theme actif du blog courant';
$GLOBALS['__l10n']['It may be useful to backup the active theme before any change or update. This compress theme folder into a single zip file.'] = 'Il peut être utile de sauvegarder le thème courant avant tout changement ou mise à jour. Ceci comprime tout le contenu du répertoire du thème dans un seul fichier Zip.';
$GLOBALS['__l10n']['Maintenance plugin has been successfully configured.'] = 'La configuration du plugin de maintenance a été enregistrée.';
$GLOBALS['__l10n']['Never'] = 'Jamais';
$GLOBALS['__l10n']['Every week'] = 'Chaque semaine';
$GLOBALS['__l10n']['Every two weeks'] = 'Toutes les deux semaines';
$GLOBALS['__l10n']['Every month'] = 'Chaque mois';
$GLOBALS['__l10n']['Every two months'] = 'Tous les deux mois';
$GLOBALS['__l10n']['You have not sufficient permissions to view this page.'] = 'Vous n\'avez pas les autorisations suffisantes pour accéder à cette page.';
$GLOBALS['__l10n']['You should execute it now.'] = 'Vous devriez l\'exécuter dès maintenant.';
$GLOBALS['__l10n']['Execute task'] = 'Exécuter cette tâche';
$GLOBALS['__l10n']['This may take a very long time.'] = 'Cela peut prendre un certain temps.';
$GLOBALS['__l10n']['Alert settings'] = 'Réglage des alertes';
$GLOBALS['__l10n']['Activation'] = 'Activation';
$GLOBALS['__l10n']['Display alert messages on late tasks'] = 'Afficher des messages d\'alerte pour les tâches en retard';
$GLOBALS['__l10n']['You can place list of late tasks on your %s.'] = 'Vous pouvez placer la liste des tâches en retard sur votre %s.';
$GLOBALS['__l10n']['Frequency'] = 'Périodicité';
$GLOBALS['__l10n']['Use one recall time for all tasks'] = 'Utiliser le même délai de rappel pour toutes les tâches';
$GLOBALS['__l10n']['Recall time for all tasks:'] = 'Délai de rappel pour toutes les tâches :';
$GLOBALS['__l10n']['Use one recall time per task'] = 'Utiliser un délai de rappel différent pour chaque tâche';
$GLOBALS['__l10n']['New page'] = 'Nouvelle page';
$GLOBALS['__l10n']['%d page'] = '%d page';
$GLOBALS['__l10n']['%d pages'] = '%d pages';
$GLOBALS['__l10n']['manage pages'] = 'gestion des pages';
$GLOBALS['__l10n']['My first page'] = 'Ma première page';
$GLOBALS['__l10n']['This is your first page. When you\'re ready to blog, log in to edit or delete it.'] = 'Ceci est votre première page. Quand vous serez prêt à bloguer, connectez-vous pour l\'éditer ou la supprimer.';
$GLOBALS['__l10n']['Published on'] = 'Publié le';
$GLOBALS['__l10n']['This page\'s comments feed'] = 'Flux des commentaires de cette page';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Vous devez indiquer une adresse e-mail valide.';
$GLOBALS['__l10n']['Page title'] = 'Titre de la page';
$GLOBALS['__l10n']['Page position'] = 'Position de la page';
$GLOBALS['__l10n']['Publication date'] = 'Date de publication';
$GLOBALS['__l10n']['Pages actions'] = 'Action sur les pages';
$GLOBALS['__l10n']['Back to pages list'] = 'Retour à la liste des pages';
$GLOBALS['__l10n']['Selected pages have been successfully reordered.'] = 'Les pages sélectionnées ont été réordonnées.';
$GLOBALS['__l10n']['No page'] = 'Aucune page';
$GLOBALS['__l10n']['Hidden'] = 'Masqué';
$GLOBALS['__l10n']['Select this page'] = 'Sélectionner cette page';
$GLOBALS['__l10n']['Are you sure you want to delete selected pages?'] = 'Êtes-vous sûr de vouloir supprimer les pages sélectionnées ?';
$GLOBALS['__l10n']['Selected pages have been successfully updated.'] = 'Les pages sélectionnées ont été modifiées.';
$GLOBALS['__l10n']['Selected pages have been successfully deleted.'] = 'Les pages sélectionnées ont été supprimées.';
$GLOBALS['__l10n']['Selected pages action:'] = 'Action sur les pages sélectionnées :';
$GLOBALS['__l10n']['To rearrange pages order, change number at the begining of the line, then click on “Save pages order” button.'] = 'Pour réordonner les pages, modifier le numéro dans le champ au début de la ligne puis cliquez sur “Enregistrer l\'ordre des pages”.';
$GLOBALS['__l10n']['To rearrange pages order, move items by drag and drop, then click on “Save pages order” button.'] = 'Pour réordonner les pages, déplacez les items par glisser déposer puis cliquez sur “Enregistrer l\'ordre des pages”.';
$GLOBALS['__l10n']['Save pages order'] = 'Enregistrer l\'ordre des pages';
$GLOBALS['__l10n']['This page does not exist.'] = 'Cette page n\'existe pas.';
$GLOBALS['__l10n']['Edit page'] = 'Modifier la page';
$GLOBALS['__l10n']['Are you sure you want to delete this page?'] = 'Êtes-vous sûr de vouloir supprimer cette page ?';
$GLOBALS['__l10n']['Page has been successfully updated.'] = 'La page a été modifiée.';
$GLOBALS['__l10n']['Page has been successfully created.'] = 'La page a été créée.';
$GLOBALS['__l10n']['Go to this page on the site'] = 'Voir cette page sur le site';
$GLOBALS['__l10n']['Page status'] = 'État de la page';
$GLOBALS['__l10n']['Page language'] = 'Langue de la page';
$GLOBALS['__l10n']['Hide in widget Pages'] = 'Ne pas lister dans le widget Pages';
$GLOBALS['__l10n']['Warning: If you set the URL manually, it may conflict with another page.'] = 'Attention : si vous définissez vous-même l\'URL, elle peut entrer en conflit avec celle d\'une autre page.';
$GLOBALS['__l10n']['Introduction to the page.'] = 'Introduction à la page.';
$GLOBALS['__l10n']['Select this comment'] = 'Sélectionner ce commentaire';
$GLOBALS['__l10n']['Pings'] = 'Signalements (pings)';
$GLOBALS['__l10n']['Settings have been successfully updated.'] = 'Les réglages ont été enregistrés.';
$GLOBALS['__l10n']['Pings configuration'] = 'Configuration des signalements';
$GLOBALS['__l10n']['Activate pings extension'] = 'Activer le plugin de signalement';
$GLOBALS['__l10n']['Service name:'] = 'Nom du service :';
$GLOBALS['__l10n']['Service URI:'] = 'URI du service :';
$GLOBALS['__l10n']['Error'] = 'Erreur';
$GLOBALS['__l10n']['Test ping services'] = 'Tester les services de signalement';
$GLOBALS['__l10n']['Check all'] = 'Tout sélectionner';
$GLOBALS['__l10n']['Simple menu'] = 'Menu simple';
$GLOBALS['__l10n']['All months'] = 'Tous les mois';
$GLOBALS['__l10n']['All tags'] = 'Tous les mots-clés';
$GLOBALS['__l10n']['Home'] = 'Accueil';
$GLOBALS['__l10n']['Archive'] = 'Archive';
$GLOBALS['__l10n']['Page'] = 'Page';
$GLOBALS['__l10n']['Tags'] = 'Mots-clés';
$GLOBALS['__l10n']['User defined'] = 'Saisie libre';
$GLOBALS['__l10n']['Configuration successfully updated.'] = 'La configuration a été mise à jour';
$GLOBALS['__l10n']['Label'] = 'Libellé';
$GLOBALS['__l10n']['Recent posts'] = 'Billets récents';
$GLOBALS['__l10n']['Switch to %s language'] = 'Basculer vers le %s';
$GLOBALS['__l10n']['Recent Posts from this category'] = 'Billets récents de cette catégorie';
$GLOBALS['__l10n']['Archives'] = 'Archives';
$GLOBALS['__l10n']['Posts from %s'] = 'Billets de %s';
$GLOBALS['__l10n']['Recent posts for %s tag'] = 'Billets récent pour le mot-clé %s';
$GLOBALS['__l10n']['Menu item has been successfully added.'] = 'L\'item de menu a été ajouté.';
$GLOBALS['__l10n']['Label and URL of menu item are mandatory.'] = 'Les libellés et URL sont obligatoires.';
$GLOBALS['__l10n']['Menu items have been successfully removed.'] = 'Le ou les items de menu ont été supprimés.';
$GLOBALS['__l10n']['No menu items selected.'] = 'Aucun item de menu sélectionné.';
$GLOBALS['__l10n']['Label is mandatory.'] = 'Le libellé est obligatoire.';
$GLOBALS['__l10n']['URL is mandatory.'] = 'l’URL est obligatoire.';
$GLOBALS['__l10n']['Menu items have been successfully updated.'] = 'Le ou les items de menu ont été mis à jour.';
$GLOBALS['__l10n']['Step #1'] = 'Étape 1';
$GLOBALS['__l10n']['Step #2'] = 'Étape 2';
$GLOBALS['__l10n']['Step #3'] = 'Étape 3';
$GLOBALS['__l10n']['Add item'] = 'Ajouter un item de menu';
$GLOBALS['__l10n']['Select type'] = 'Sélection du type';
$GLOBALS['__l10n']['Type of item menu:'] = 'Type d\'item de menu :';
$GLOBALS['__l10n']['Continue...'] = 'Continuer…';
$GLOBALS['__l10n']['Select language:'] = 'Sélectionnez la langue :';
$GLOBALS['__l10n']['Select category:'] = 'Sélectionnez la catégorie :';
$GLOBALS['__l10n']['Select month (if necessary):'] = 'Sélectionnez le mois (si nécessaire) :';
$GLOBALS['__l10n']['Select page:'] = 'Sélectionnez la page :';
$GLOBALS['__l10n']['Select tag (if necessary):'] = 'Sélectionnez le mot clé (si nécessaire) :';
$GLOBALS['__l10n']['Label of item menu:'] = 'Libellé de l\'item de menu :';
$GLOBALS['__l10n']['Description of item menu:'] = 'Description de l\'item de menu :';
$GLOBALS['__l10n']['URL of item menu:'] = 'URL de l\'item de menu :';
$GLOBALS['__l10n']['Add this item'] = 'Ajouter cet item';
$GLOBALS['__l10n']['Enable simple menu for this blog'] = 'Activer le menu simple pour ce blog';
$GLOBALS['__l10n']['Save configuration'] = 'Enregistrer la configuration';
$GLOBALS['__l10n']['Add an item'] = 'Ajouter un item de menu';
$GLOBALS['__l10n']['Menu items list'] = 'Liste des items de menu';
$GLOBALS['__l10n']['Update menu'] = 'Mettre à jour le menu';
$GLOBALS['__l10n']['Delete selected menu items'] = 'Supprimer les items de menu sélectionnés';
$GLOBALS['__l10n']['Are you sure you want to remove selected menu items?'] = 'Êtes-vous sûr de vouloir supprimer les items de menu sélectionnés ?';
$GLOBALS['__l10n']['No menu items so far.'] = 'Aucun item de menu pour l\'instant.';
$GLOBALS['__l10n']['Add tags'] = 'Ajouter des mots-clés';
$GLOBALS['__l10n']['Remove tags'] = 'Retirer des mots-clés';
$GLOBALS['__l10n']['Tag has been successfully added to selected entries'][0] = 'Le mot-clé a été ajouté aux entrées sélectionnées';
$GLOBALS['__l10n']['Tag has been successfully added to selected entries'][1] = 'Les mot-clés ont été ajoutés aux entrées sélectionnées';
$GLOBALS['__l10n']['Add tags to this selection'] = 'Ajouter des mots-clés à cette sélection';
$GLOBALS['__l10n']['Are you sure you want to remove this tag?'] = 'Êtes-vous sûr de vouloir supprimer ce mot-clé ?';
$GLOBALS['__l10n']['Add a tag to this entry'] = 'Ajouter un mot-clé à ce billet';
$GLOBALS['__l10n']['Choose from list'] = 'Choisir dans la liste';
$GLOBALS['__l10n']['all'] = 'tous';
$GLOBALS['__l10n']['Enter tags separated by coma'] = 'Séparez les mot-clés par des virgules';
$GLOBALS['__l10n']['used in %e - frequency %p%'] = 'utilisé dans %e - fréquence %p%';
$GLOBALS['__l10n']['entry'] = 'billet';
$GLOBALS['__l10n']['entries'] = 'billets';
$GLOBALS['__l10n']['Tags to add:'] = 'Mots-clés à ajouter :';
$GLOBALS['__l10n']['Tag has been successfully removed from selected entries'][0] = 'Le mot-clé a été retiré des entrées sélectionnées';
$GLOBALS['__l10n']['Tag has been successfully removed from selected entries'][1] = 'Les mot-clés ont été retirés des entrées sélectionnées';
$GLOBALS['__l10n']['No tags for selected entries'] = 'Aucun mot-clé pour les billets sélectionnés';
$GLOBALS['__l10n']['Remove selected tags from this selection'] = 'Retirer les mots-clés de cette sélection';
$GLOBALS['__l10n']['Following tags have been found in selected entries:'] = 'Les mots-clés suivants ont été trouvés pour les billets sélectionnés :';
$GLOBALS['__l10n']['Tag'] = 'Mot-clé';
$GLOBALS['__l10n']['Short'] = 'Court';
$GLOBALS['__l10n']['Extended'] = 'Étendu';
$GLOBALS['__l10n']['Tags list format:'] = 'Format de la liste des mots-clés :';
$GLOBALS['__l10n']['This tag\'s comments Atom feed'] = 'Flux Atom des commentaires associés à ce mot-clé';
$GLOBALS['__l10n']['This tag\'s entries Atom feed'] = 'Flux Atom des billets associés à ce mot-clé';
$GLOBALS['__l10n']['Limit (empty means no limit):'] = 'Limite (laisser vide si pas de limite) :';
$GLOBALS['__l10n']['Entries count'] = 'Nombre de billets';
$GLOBALS['__l10n']['Tag name'] = 'Nom du mot-clé';
$GLOBALS['__l10n']['Link to all tags:'] = 'Lien vers tous les mots-clés :';
$GLOBALS['__l10n']['Tag has been successfully renamed'] = 'Le mot-clé a été renommé.';
$GLOBALS['__l10n']['Tag has been successfully removed'] = 'Le mot-clé a été retiré.';
$GLOBALS['__l10n']['Are you sure you want to remove tag: “%s”?'] = 'Êtes-vous sûr de vouloir supprimer le mot-clé “%s” ?';
$GLOBALS['__l10n']['Back to tags list'] = 'Retour à la liste des mots-clés';
$GLOBALS['__l10n']['Rename'] = 'Renommer';
$GLOBALS['__l10n']['Delete this tag'] = 'Supprimer ce mot-clé';
$GLOBALS['__l10n']['List of entries with the tag “%s”'] = 'Liste des billets avec le mot-clé “%s”';
$GLOBALS['__l10n']['No tags on this blog.'] = 'Aucun mot-clé sur ce blog.';
$GLOBALS['__l10n']['Edit theme files'] = 'Modifier les fichiers du thème';
$GLOBALS['__l10n']['Syntax highlighting in theme editor'] = 'Coloration syntaxique de l\'éditeur de thème';
$GLOBALS['__l10n']['No file'] = 'Aucun fichier';
$GLOBALS['__l10n']['From theme:'] = 'Du thème :';
$GLOBALS['__l10n']['From parent:'] = 'Du thème parent :';
$GLOBALS['__l10n']['From template set:'] = 'Du jeu de template :';
$GLOBALS['__l10n']['File does not exist.'] = 'Ce fichier n\'existe pas.';
$GLOBALS['__l10n']['File %s is not readable'] = 'Le fichier %s n\'est pas lisible';
$GLOBALS['__l10n']['Unable to write file %s. Please check your theme files and folders permissions.'] = 'Impossible d\'écrire le fichier %s. Contrôlez les permissions des fichiers et des répertoires de votre thème.';
$GLOBALS['__l10n']['Unable to delete file %s. Please check your theme files and folders permissions.'] = 'Impossible de supprimer le fichier %s. Contrôlez les permissions des fichiers et des répertoires de votre thème.';
$GLOBALS['__l10n']['The file has been reset.'] = 'Le fichier a été réinitialisé.';
$GLOBALS['__l10n']['Saving document...'] = 'Enregistrement du document…';
$GLOBALS['__l10n']['Document saved'] = 'Document enregistré';
$GLOBALS['__l10n']['An error occurred:'] = 'Une erreur est survenue :';
$GLOBALS['__l10n']['Are you sure you want to reset this file?'] = 'Êtes-vous sûr de vouloir réinitialiser ce fichier ?';
$GLOBALS['__l10n']['Your current theme on this blog is "%s".'] = 'Actuellement votre thème sur ce blog est « %s ».';
$GLOBALS['__l10n']['You can\'t edit default theme.'] = 'Vous ne pouvez pas modifier le thème par défaut.';
$GLOBALS['__l10n']['Please select a file to edit.'] = 'Sélectionnez un fichier à modifier.';
$GLOBALS['__l10n']['File editor'] = 'Éditeur de fichier';
$GLOBALS['__l10n']['Editing file %s'] = 'Édition du fichier %s';
$GLOBALS['__l10n']['Reset'] = 'Réinitialiser';
$GLOBALS['__l10n']['This file is not writable. Please check your theme files permissions.'] = 'Ce fichier n\'est pas modifiable. Contrôlez les permissions de vos fichiers de thème.';
$GLOBALS['__l10n']['Templates files'] = 'Fichiers du thème';
$GLOBALS['__l10n']['CSS files'] = 'Fichiers CSS';
$GLOBALS['__l10n']['JavaScript files'] = 'Fichiers JavaScript';
$GLOBALS['__l10n']['Locales files'] = 'Fichiers de traduction';
$GLOBALS['__l10n']['Preferences successfully updated'] = 'Les préférences ont été mises à jour.';
$GLOBALS['__l10n']['user:preferences'] = 'user:preferences';
$GLOBALS['__l10n']['User preferences'] = 'Préférences utilisateur';
$GLOBALS['__l10n']['Global preferences'] = 'Préférences globales';
$GLOBALS['__l10n']['Presentation widgets'] = 'Widgets de présentation';
$GLOBALS['__l10n']['Search engine'] = 'Moteur de recherche';
$GLOBALS['__l10n']['Navigation links'] = 'Liens de navigation';
$GLOBALS['__l10n']['Selected entries'] = 'Billets sélectionnés';
$GLOBALS['__l10n']['Best of me'] = 'À retenir';
$GLOBALS['__l10n']['Blog languages'] = 'Langues du blog';
$GLOBALS['__l10n']['With entries counts'] = 'Avec le nombre de billets';
$GLOBALS['__l10n']['Include sub cats in count'] = 'Inclure les sous-catégories dans les compteurs';
$GLOBALS['__l10n']['Include empty categories'] = 'Inclure les catégories vides';
$GLOBALS['__l10n']['Subscribe links'] = 'Liens de souscription';
$GLOBALS['__l10n']['Subscribe'] = 'S\'abonner';
$GLOBALS['__l10n']['Feeds type:'] = 'Type de flux :';
$GLOBALS['__l10n']['Feed reader'] = 'Lecteur de flux';
$GLOBALS['__l10n']['Somewhere else'] = 'Autre part';
$GLOBALS['__l10n']['Entries limit:'] = 'Limite du nombre de billets :';
$GLOBALS['__l10n']['Text'] = 'Texte';
$GLOBALS['__l10n']['Text:'] = 'Texte :';
$GLOBALS['__l10n']['Last entries'] = 'Derniers billets';
$GLOBALS['__l10n']['Uncategorized'] = 'Sans catégorie';
$GLOBALS['__l10n']['Tag:'] = 'Mot-clé :';
$GLOBALS['__l10n']['Last comments'] = 'Derniers commentaires';
$GLOBALS['__l10n']['Comments limit:'] = 'Limite du nombre de commentaires :';
$GLOBALS['__l10n']['This blog\'s entries %s feed'] = 'Flux %s des billets de ce blog';
$GLOBALS['__l10n']['This blog\'s comments %s feed'] = 'Flux %s des commentaires de ce blog';
$GLOBALS['__l10n']['Entries feed'] = 'Fil des billets';
$GLOBALS['__l10n']['Comments feed'] = 'Fil des commentaires';
$GLOBALS['__l10n']['navigation'] = 'Volet de navigation';
$GLOBALS['__l10n']['extra'] = 'Volet d\'extra';
$GLOBALS['__l10n']['custom'] = 'Volet supplémentaire';
$GLOBALS['__l10n']['empty string'] = 'chaîne vide';
$GLOBALS['__l10n']['Sidebars and their widgets have been saved.'] = 'Les volets et leurs widgets ont été enregistrés.';
$GLOBALS['__l10n']['Sidebars have been resetting.'] = 'Les volets ont été réinitialisés.';
$GLOBALS['__l10n']['Widgets'] = 'Widgets';
$GLOBALS['__l10n']['Are you sure you want to reset sidebars?'] = 'Êtes-vous sûr de vouloir réinitialiser les volets ?';
$GLOBALS['__l10n']['Available widgets'] = 'Widgets disponibles';
$GLOBALS['__l10n']['Drag widgets from this list to one of the sidebars, for add.'] = 'Déplacez des widgets de cette liste vers l\'un des volets.';
$GLOBALS['__l10n']['order'] = 'ordre';
$GLOBALS['__l10n']['Append to:'] = 'Ajouter à :';
$GLOBALS['__l10n']['Add widgets to sidebars'] = 'Ajouter les widgets aux volets';
$GLOBALS['__l10n']['Navigation sidebar'] = 'Volet de navigation';
$GLOBALS['__l10n']['Extra sidebar'] = 'Volet d\'extra';
$GLOBALS['__l10n']['Custom sidebar'] = 'Volet supplémentaire';
$GLOBALS['__l10n']['Update sidebars'] = 'Mettre à jour les volets';
$GLOBALS['__l10n']['Reset sidebars'] = 'Réinitialiser les volets';
$GLOBALS['__l10n']['Widget ID:'] = 'Identifiant du widget :';
$GLOBALS['__l10n']['No setting for this widget'] = 'Aucun réglage pour ce widget';
$GLOBALS['__l10n']['boolean'] = 'booléen';
$GLOBALS['__l10n']['possible values:'] = 'valeurs possibles :';
$GLOBALS['__l10n']['listitem'] = 'élément de liste';
$GLOBALS['__l10n']['string'] = 'chaîne de caractères';
$GLOBALS['__l10n']['Setting name:'] = 'Nom de l\'élément de réglage :';
$GLOBALS['__l10n']['No widget as far.'] = 'Aucun widget pour le moment.';
$GLOBALS['__l10n']['Up the widget'] = 'Monter le widget';
$GLOBALS['__l10n']['Down the widget'] = 'Descendre le widget';
$GLOBALS['__l10n']['Remove the widget'] = 'Retirer le widget';
$GLOBALS['__l10n']['Remove widget'] = 'Retirer le widget';
$GLOBALS['__l10n']['Drag widgets here to remove.'] = 'Glisser les widgets ici pour les retirer du volet.';
